@@ -1,7 +1,6 @@
-# pylint: disable=missing-module-docstring
 import logging
 
-__version__ = "0.28.0"
+__version__ = "1.2.0"
 
 # Configure a basic 'securesystemslib' top-level logger with a StreamHandler
 # (print to console) and the WARNING log level (print messages of type
@@ -12,10 +11,3 @@ __version__ = "0.28.0"
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.WARNING)
 logger.addHandler(logging.StreamHandler())
-
-
-# Global constants
-# TODO: Replace hard-coded key types with these constants (and add more)
-KEY_TYPE_RSA = "rsa"
-KEY_TYPE_ED25519 = "ed25519"
-KEY_TYPE_ECDSA = "ecdsa"
