@@ -1,18 +1,15 @@
 """Signer implementation for Google Cloud KMS"""
 
+from __future__ import annotations
+
 import logging
-from typing import Optional, Tuple
 from urllib import parse
 
 import securesystemslib.hash as sslib_hash
 from securesystemslib import exceptions
-from securesystemslib.signer._key import Key
-from securesystemslib.signer._signer import (
-    SecretsHandler,
-    Signature,
-    Signer,
-    SSlibKey,
-)
+from securesystemslib.signer._key import Key, SSlibKey
+from securesystemslib.signer._signer import SecretsHandler, Signature, Signer
+from securesystemslib.signer._utils import compute_default_keyid
 
 logger = logging.getLogger(__name__)
 
@@ -65,16 +62,20 @@ class GCPSigner(Signer):
 
         self.hash_algorithm = self._get_hash_algorithm(public_key)
         self.gcp_keyid = gcp_keyid
-        self.public_key = public_key
+        self._public_key = public_key
         self.client = kms.KeyManagementServiceClient()
 
+    @property
+    def public_key(self) -> Key:
+        return self._public_key
+
     @classmethod
     def from_priv_key_uri(
         cls,
         priv_key_uri: str,
         public_key: Key,
-        secrets_handler: Optional[SecretsHandler] = None,
-    ) -> "GCPSigner":
+        secrets_handler: SecretsHandler | None = None,
+    ) -> GCPSigner:
         uri = parse.urlparse(priv_key_uri)
 
         if uri.scheme != cls.SCHEME:
@@ -83,7 +84,7 @@ class GCPSigner(Signer):
         return cls(uri.path, public_key)
 
     @classmethod
-    def import_(cls, gcp_keyid: str) -> Tuple[str, Key]:
+    def import_(cls, gcp_keyid: str) -> tuple[str, Key]:
         """Load key and signer details from KMS
 
         Returns the private key uri and the public key. This method should only
@@ -103,13 +104,13 @@ class GCPSigner(Signer):
             ) from e
 
         keyval = {"public": kms_pubkey.pem}
-        keyid = cls._get_keyid(keytype, scheme, keyval)
+        keyid = compute_default_keyid(keytype, scheme, keyval)
         public_key = SSlibKey(keyid, keytype, scheme, keyval)
 
         return f"{cls.SCHEME}:{gcp_keyid}", public_key
 
     @staticmethod
-    def _get_keytype_and_scheme(algorithm: int) -> Tuple[str, str]:
+    def _get_keytype_and_scheme(algorithm: int) -> tuple[str, str]:
         """Return keytype and scheme for the KMS algorithm enum"""
         keytypes_and_schemes = {
             CryptoKeyVersion.CryptoKeyVersionAlgorithm.EC_SIGN_P256_SHA256: (
@@ -165,7 +166,7 @@ class GCPSigner(Signer):
         if public_key.keytype == "rsa":
             # hash algorithm is encoded as last scheme portion
             algo = public_key.scheme.split("-")[-1]
-        if public_key.keytype in [
+        elif public_key.keytype in [
             "ecdsa",
             "ecdsa-sha2-nistp256",
             "ecdsa-sha2-nistp384",
@@ -173,6 +174,10 @@ class GCPSigner(Signer):
             # nistp256 uses sha-256, nistp384 uses sha-384
             bits = public_key.scheme.split("-nistp")[-1]
             algo = f"sha{bits}"
+        else:
+            raise exceptions.UnsupportedAlgorithmError(
+                f"Unsupported key type {public_key.keytype} in key {public_key.keyid}"
+            )
 
         # trigger UnsupportedAlgorithm if appropriate
         _ = sslib_hash.digest(algo)
