@@ -4,19 +4,23 @@ Uses PKCS#11/Cryptoki API to create signatures with HSMs (e.g. YubiKey) and to e
 the related public keys.
 
 """
+
+from __future__ import annotations
+
 import binascii
+from collections.abc import Iterator
 from contextlib import contextmanager
-from typing import Dict, Iterator, List, Optional, Tuple
 from urllib import parse
 
-from securesystemslib import KEY_TYPE_ECDSA
 from securesystemslib.exceptions import UnsupportedLibraryError
 from securesystemslib.hash import digest
 from securesystemslib.signer._key import Key, SSlibKey
 from securesystemslib.signer._signature import Signature
 from securesystemslib.signer._signer import SecretsHandler, Signer
+from securesystemslib.signer._utils import compute_default_keyid
+
+_KEY_TYPE_ECDSA = "ecdsa"
 
-# pylint: disable=wrong-import-position
 CRYPTO_IMPORT_ERROR = None
 try:
     from cryptography.hazmat.primitives import serialization
@@ -49,21 +53,20 @@ except ImportError:
 
 ASN1_IMPORT_ERROR = None
 try:
-    from asn1crypto.keys import (  # pylint: disable=import-error
+    from asn1crypto.keys import (
         ECDomainParameters,
         ECPoint,
     )
 except ImportError:
     ASN1_IMPORT_ERROR = "'asn1crypto' required"
-# pylint: enable=wrong-import-position
 
 
 _PYKCS11LIB = None
 
 
-def PYKCS11LIB():
+def PYKCS11LIB():  # noqa: N802
     """Pseudo-singleton to load shared library using PYKCS11LIB envvar only once."""
-    global _PYKCS11LIB  # pylint: disable=global-statement
+    global _PYKCS11LIB  # noqa: PLW0603
     if _PYKCS11LIB is None:
         _PYKCS11LIB = PyKCS11.PyKCS11Lib()
         _PYKCS11LIB.load()
@@ -124,7 +127,7 @@ class HSMSigner(Signer):
     def __init__(
         self,
         hsm_keyid: int,
-        token_filter: Dict[str, str],
+        token_filter: dict[str, str],
         public_key: Key,
         pin_handler: SecretsHandler,
     ):
@@ -142,17 +145,21 @@ class HSMSigner(Signer):
 
         self.hsm_keyid = hsm_keyid
         self.token_filter = token_filter
-        self.public_key = public_key
+        self._public_key = public_key
         self.pin_handler = pin_handler
 
+    @property
+    def public_key(self) -> Key:
+        return self._public_key
+
     @staticmethod
-    def _find_pkcs_slot(filters: Dict[str, str]) -> int:
+    def _find_pkcs_slot(filters: dict[str, str]) -> int:
         """Return the PKCS slot with initialized token that matches filter
 
         Raises ValueError if more or less than 1 PKCS slot is found.
         """
         lib = PYKCS11LIB()
-        slots: List[int] = []
+        slots: list[int] = []
         for slot in lib.getSlotList(tokenPresent=True):
             tokeninfo = lib.getTokenInfo(slot)
             if not tokeninfo.flags & PyKCS11.CKF_TOKEN_INITIALIZED:
@@ -178,7 +185,7 @@ class HSMSigner(Signer):
 
     @staticmethod
     @contextmanager
-    def _get_session(filters: Dict[str, str]) -> Iterator["PyKCS11.Session"]:
+    def _get_session(filters: dict[str, str]) -> Iterator[PyKCS11.Session]:
         """Context manager to handle a HSM session.
 
         The cryptographic token is selected by filtering by token info fields.
@@ -195,9 +202,9 @@ class HSMSigner(Signer):
     @classmethod
     def _find_key(
         cls,
-        session: "PyKCS11.Session",
+        session: PyKCS11.Session,
         keyid: int,
-        key_type: Optional[int] = None,
+        key_type: int | None = None,
     ) -> int:
         """Find ecdsa key on HSM."""
         if key_type is None:
@@ -211,19 +218,17 @@ class HSMSigner(Signer):
             ]
         )
         if not keys:
-            raise ValueError(f"could not find {KEY_TYPE_ECDSA} key for {keyid}")
+            raise ValueError(f"could not find {_KEY_TYPE_ECDSA} key for {keyid}")
 
         if len(keys) > 1:
-            raise ValueError(
-                f"found more than one {KEY_TYPE_ECDSA} key for {keyid}"
-            )
+            raise ValueError(f"found more than one {_KEY_TYPE_ECDSA} key for {keyid}")
 
         return keys[0]
 
     @classmethod
     def _find_key_values(
-        cls, session: "PyKCS11.Session", keyid: int
-    ) -> Tuple["ECDomainParameters", bytes]:
+        cls, session: PyKCS11.Session, keyid: int
+    ) -> tuple[ECDomainParameters, bytes]:
         """Find ecdsa public key values on HSM."""
         key = cls._find_key(session, keyid)
         params, point = session.getAttributeValue(
@@ -232,7 +237,7 @@ class HSMSigner(Signer):
         return ECDomainParameters.load(bytes(params)), bytes(point)
 
     @classmethod
-    def _build_token_filter(cls) -> Dict[str, str]:
+    def _build_token_filter(cls) -> dict[str, str]:
         """Builds a token filter for the found cryptographic token.
 
         The filter will include 'label' if one is found on token.
@@ -257,9 +262,9 @@ class HSMSigner(Signer):
     @classmethod
     def import_(
         cls,
-        hsm_keyid: Optional[int] = None,
-        token_filter: Optional[Dict[str, str]] = None,
-    ) -> Tuple[str, SSlibKey]:
+        hsm_keyid: int | None = None,
+        token_filter: dict[str, str] | None = None,
+    ) -> tuple[str, SSlibKey]:
         """Import public key and signer details from HSM.
 
         Either only one cryptographic token must be present when importing or a
@@ -270,7 +275,8 @@ class HSMSigner(Signer):
         key should be stored for later use.
 
         Arguments:
-            hsm_keyid: Key identifier on the token. Default is 2 (meaning PIV key slot 9c).
+            hsm_keyid: Key identifier on the token.
+                Default is 2 (meaning PIV key slot 9c).
             token_filter: Dictionary of token field names and values used to
                 filter the correct cryptographic token. If no filter is
                 provided one is built from the fields found on the token.
@@ -303,7 +309,8 @@ class HSMSigner(Signer):
 
         if params.chosen.native not in _CURVE_NAMES:
             raise ValueError(
-                f"found key on {params.chosen.native}, should be on one of {_CURVE_NAMES}"
+                f"found key on {params.chosen.native}, "
+                f"should be on one of {_CURVE_NAMES}"
             )
 
         # Create PEM from key
@@ -321,8 +328,8 @@ class HSMSigner(Signer):
 
         keyval = {"public": public_pem}
         scheme = _SCHEME_FOR_CURVE[curve]
-        keyid = cls._get_keyid(KEY_TYPE_ECDSA, scheme, keyval)
-        key = SSlibKey(keyid, KEY_TYPE_ECDSA, scheme, keyval)
+        keyid = compute_default_keyid(_KEY_TYPE_ECDSA, scheme, keyval)
+        key = SSlibKey(keyid, _KEY_TYPE_ECDSA, scheme, keyval)
 
         return uri, key
 
@@ -331,8 +338,8 @@ class HSMSigner(Signer):
         cls,
         priv_key_uri: str,
         public_key: Key,
-        secrets_handler: Optional[SecretsHandler] = None,
-    ) -> "HSMSigner":
+        secrets_handler: SecretsHandler | None = None,
+    ) -> HSMSigner:
         if not isinstance(public_key, SSlibKey):
             raise ValueError(f"expected SSlibKey for {priv_key_uri}")
 
@@ -369,9 +376,7 @@ class HSMSigner(Signer):
         pin = self.pin_handler(self.SECRETS_HANDLER_MSG)
         with self._get_session(self.token_filter) as session:
             session.login(pin)
-            key = self._find_key(
-                session, self.hsm_keyid, PyKCS11.CKO_PRIVATE_KEY
-            )
+            key = self._find_key(session, self.hsm_keyid, PyKCS11.CKO_PRIVATE_KEY)
             mechanism = PyKCS11.Mechanism(PyKCS11.CKM_ECDSA)
             signature = session.sign(key, hasher.digest(), mechanism)
             session.logout()
@@ -385,8 +390,6 @@ class HSMSigner(Signer):
         s = int.from_bytes(signature[r_s_len:], byteorder="big")
 
         # Create an ASN.1 encoded Dss-Sig-Value to be used with pyca/cryptography
-        dss_sig_value = binascii.hexlify(encode_dss_signature(r, s)).decode(
-            "ascii"
-        )
+        dss_sig_value = binascii.hexlify(encode_dss_signature(r, s)).decode("ascii")
 
         return Signature(self.public_key.keyid, dss_sig_value)
