@@ -12,7 +12,7 @@
   See LICENSE for licensing information.
 
 <Purpose>
-  Check that the public facing 'gpg.functions' module remains importable if
+  Check that the public facing '_gpg.functions' module remains importable if
   gnupg is not installed, and that each function presents meaningful
   user-feedback.
   Further check that gpg signature verification works even without gpg.
@@ -25,20 +25,18 @@
 
 import unittest
 
-from securesystemslib.exceptions import UnsupportedLibraryError
-from securesystemslib.gpg.constants import NO_GPG_MSG, have_gpg
-from securesystemslib.gpg.functions import (
+from securesystemslib._gpg.constants import NO_GPG_MSG, have_gpg
+from securesystemslib._gpg.functions import (
     create_signature,
     export_pubkey,
     export_pubkeys,
     verify_signature,
 )
+from securesystemslib.exceptions import UnsupportedLibraryError
 from securesystemslib.signer import GPGKey, GPGSigner, Signer
 
 
-class TestPublicInterfacesGPG(
-    unittest.TestCase
-):  # pylint: disable=missing-class-docstring
+class TestPublicInterfacesGPG(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         assert (
@@ -150,7 +148,6 @@ class TestPublicInterfacesGPG(
 
         for key, sig in key_signature_pairs:
             self.assertTrue(verify_signature(sig, key, data))
-            # pylint: disable=protected-access
             GPGSigner._key_from_legacy_dict(key).verify_signature(
                 GPGSigner._sig_from_legacy_dict(sig), data
             )
