@@ -22,17 +22,16 @@ import shutil
 import tempfile
 import unittest
 
-# pylint: disable=wrong-import-position
 from collections import OrderedDict
 from copy import deepcopy
 from unittest.mock import patch
 
+# ruff: noqa: I001
 import cryptography.hazmat.primitives.hashes as hashing
 from cryptography.hazmat import backends
 from cryptography.hazmat.primitives import serialization
 
-from securesystemslib.formats import ANY_PUBKEY_DICT_SCHEMA, GPG_PUBKEY_SCHEMA
-from securesystemslib.gpg.common import (
+from securesystemslib._gpg.common import (
     _assign_certified_key_info,
     _get_verified_subkeys,
     get_pubkey_bundle,
@@ -40,7 +39,7 @@ from securesystemslib.gpg.common import (
     parse_pubkey_payload,
     parse_signature_packet,
 )
-from securesystemslib.gpg.constants import (
+from securesystemslib._gpg.constants import (
     PACKET_TYPE_PRIMARY_KEY,
     PACKET_TYPE_SUB_KEY,
     PACKET_TYPE_USER_ATTR,
@@ -50,39 +49,34 @@ from securesystemslib.gpg.constants import (
     SHA512,
     have_gpg,
 )
-from securesystemslib.gpg.dsa import create_pubkey as dsa_create_pubkey
-from securesystemslib.gpg.eddsa import ED25519_SIG_LENGTH
-from securesystemslib.gpg.exceptions import (
-    CommandError,
+from securesystemslib._gpg.dsa import create_pubkey as dsa_create_pubkey
+from securesystemslib._gpg.eddsa import ED25519_SIG_LENGTH
+from securesystemslib._gpg.exceptions import (
     KeyExpirationError,
     KeyNotFoundError,
     PacketParsingError,
     PacketVersionNotSupportedError,
     SignatureAlgorithmNotSupportedError,
 )
-from securesystemslib.gpg.functions import (
+from securesystemslib._gpg.functions import (
     create_signature,
     export_pubkey,
     export_pubkeys,
     verify_signature,
 )
-from securesystemslib.gpg.rsa import create_pubkey as rsa_create_pubkey
-from securesystemslib.gpg.util import (
+from securesystemslib._gpg.rsa import create_pubkey as rsa_create_pubkey
+from securesystemslib._gpg.util import (
     get_hashing_class,
     parse_packet_header,
     parse_subpacket_header,
 )
 
-# pylint: enable=wrong-import-position
-
 
 class GPGTestUtils:
     """GPG Test utility class"""
 
     @staticmethod
-    def ignore_not_found_error(
-        function, path, exc_info
-    ):  # pylint: disable=unused-argument,unused-argument
+    def ignore_not_found_error(function, path, exc_info):
         """Callback that ignores FileNotFoundError"""
         _, error, _ = exc_info
         if not isinstance(error, FileNotFoundError):
@@ -197,10 +191,10 @@ class TestUtil(unittest.TestCase):
 
 @unittest.skipIf(not have_gpg(), "gpg not found")
 class TestCommon(unittest.TestCase):
-    """Test common functions of the securesystemslib.gpg module."""
+    """Test common functions of the securesystemslib._gpg module."""
 
     @classmethod
-    def setUpClass(self):  # pylint: disable=bad-classmethod-argument
+    def setUpClass(cls):
         gpg_keyring_path = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "rsa"
         )
@@ -214,9 +208,9 @@ class TestCommon(unittest.TestCase):
             with open(path, "rb") as f:
                 data[keyid] = f.read()
 
-        self.raw_key_data = data[key]
-        self.raw_key_bundle = parse_pubkey_bundle(data[key])
-        self.raw_expired_key_bundle = parse_pubkey_bundle(data[key_expired])
+        cls.raw_key_data = data[key]
+        cls.raw_key_bundle = parse_pubkey_bundle(data[key])
+        cls.raw_expired_key_bundle = parse_pubkey_bundle(data[key_expired])
 
     def test_parse_pubkey_payload_errors(self):
         """Test parse_pubkey_payload errors with manually crafted data."""
@@ -245,14 +239,10 @@ class TestCommon(unittest.TestCase):
         based on real gpg key data (see self.raw_key_bundle)."""
         # Extract sample (legitimate) user ID packet and pass as first packet to
         # raise first packet must be primary key error
-        user_id_packet = list(self.raw_key_bundle[PACKET_TYPE_USER_ID].keys())[
-            0
-        ]
+        user_id_packet = list(self.raw_key_bundle[PACKET_TYPE_USER_ID].keys())[0]
         # Extract sample (legitimate) primary key packet and pass as first two
         # packets to raise unexpected second primary key error
-        primary_key_packet = self.raw_key_bundle[PACKET_TYPE_PRIMARY_KEY][
-            "packet"
-        ]
+        primary_key_packet = self.raw_key_bundle[PACKET_TYPE_PRIMARY_KEY]["packet"]
         # Create incomplete packet to re-raise header parsing IndexError as
         # PacketParsingError
         incomplete_packet = bytearray([0b01111111])
@@ -272,7 +262,7 @@ class TestCommon(unittest.TestCase):
         # Create empty packet of unsupported type 66 (bit 0-5) and length 0 and
         # pass as second packet to provoke skipping of unsupported packet
         unsupported_packet = bytearray([0b01111111, 0])
-        with patch("securesystemslib.gpg.common.log") as mock_log:
+        with patch("securesystemslib._gpg.common.log") as mock_log:
             parse_pubkey_bundle(primary_key_packet + unsupported_packet)
             self.assertTrue(
                 "Ignoring gpg key packet '63'" in mock_log.info.call_args[0][0]
@@ -286,11 +276,10 @@ class TestCommon(unittest.TestCase):
         gpg --list-packets
     ```
     """
-        # Expect parsed primary key matching GPG_PUBKEY_SCHEMA
-        self.assertTrue(
-            GPG_PUBKEY_SCHEMA.matches(
-                self.raw_key_bundle[PACKET_TYPE_PRIMARY_KEY]["key"]
-            )
+        # Expect parsed primary key
+        self.assertEqual(
+            self.raw_key_bundle[PACKET_TYPE_PRIMARY_KEY]["key"]["method"],
+            "pgp+rsa-pkcsv1.5",
         )
 
         # Parse corresponding raw packet for comparison
@@ -298,12 +287,9 @@ class TestCommon(unittest.TestCase):
             self.raw_key_bundle[PACKET_TYPE_PRIMARY_KEY]["packet"]
         )
 
-        # pylint: disable=unsubscriptable-object
         parsed_raw_packet = parse_pubkey_payload(
             bytearray(
-                self.raw_key_bundle[PACKET_TYPE_PRIMARY_KEY]["packet"][
-                    header_len:
-                ]
+                self.raw_key_bundle[PACKET_TYPE_PRIMARY_KEY]["packet"][header_len:]
             )
         )
 
@@ -352,9 +338,9 @@ class TestCommon(unittest.TestCase):
 
         # Replace primary key id with a non-associated keyid
         wrong_keyid_bundle = deepcopy(self.raw_key_bundle)
-        wrong_keyid_bundle[PACKET_TYPE_PRIMARY_KEY]["key"][
-            "keyid"
-        ] = "8465A1E2E0FB2B40ADB2478E18FB3F537E0C8A17"
+        wrong_keyid_bundle[PACKET_TYPE_PRIMARY_KEY]["key"]["keyid"] = (
+            "8465A1E2E0FB2B40ADB2478E18FB3F537E0C8A17"
+        )
 
         # Remove a byte in user id packet to make signature verification fail
         invalid_cert_bundle = deepcopy(self.raw_key_bundle)
@@ -372,15 +358,10 @@ class TestCommon(unittest.TestCase):
         ]
 
         for bundle, expected_msg in test_data:
-            with patch("securesystemslib.gpg.common.log") as mock_log:
+            with patch("securesystemslib._gpg.common.log") as mock_log:
                 _assign_certified_key_info(bundle)
                 msg = str(mock_log.info.call_args[0][0])
-                self.assertTrue(
-                    expected_msg in msg,
-                    "'{}' not in '{}'".format(  # pylint: disable=consider-using-f-string
-                        expected_msg, msg
-                    ),
-                )
+                self.assertTrue(expected_msg in msg, f"'{expected_msg}' not in '{msg}'")
 
     def test_assign_certified_key_info_expiration(self):
         """Test assignment of key expiration date in
@@ -408,7 +389,9 @@ class TestCommon(unittest.TestCase):
         # "Test Expiration II" has the primary user ID flag set and therefor has
         # the highest priority.
         key = _assign_certified_key_info(self.raw_expired_key_bundle)
-        self.assertTrue(key["validity_period"] == 87901)  # ~ 1 day
+        self.assertTrue(
+            key["validity_period"] == 87901  # noqa: PLR2004
+        )  # ~ 1 day
 
         # Test ambiguity resolution scheme with 2 User IDs
         #   :user ID packet: "Test Expiration III <test@expir.three>"
@@ -417,13 +400,13 @@ class TestCommon(unittest.TestCase):
         # Neither packet has the primary user ID flag set.
         # "Test Expiration III" has the highest priority.
         raw_key_bundle = deepcopy(self.raw_expired_key_bundle)
-        user_id_items = list(
-            reversed(raw_key_bundle[PACKET_TYPE_USER_ID].items())
-        )
+        user_id_items = list(reversed(raw_key_bundle[PACKET_TYPE_USER_ID].items()))
         del user_id_items[1]
         raw_key_bundle[PACKET_TYPE_USER_ID] = OrderedDict(user_id_items)
         key = _assign_certified_key_info(raw_key_bundle)
-        self.assertTrue(key["validity_period"] == 87901)  # ~ 1 day
+        self.assertTrue(
+            key["validity_period"] == 87901  # noqa: PLR2004
+        )  # ~ 1 day
 
     def test_get_verified_subkeys_errors(self):
         """Test _get_verified_subkeys errors with manually crafted data based on
@@ -450,25 +433,21 @@ class TestCommon(unittest.TestCase):
 
         # Remove sigs to trigger not enough sigs error
         not_enough_sigs_bundle = deepcopy(self.raw_key_bundle)
-        packet, packet_data = not_enough_sigs_bundle[
-            PACKET_TYPE_SUB_KEY
-        ].popitem()
+        packet, packet_data = not_enough_sigs_bundle[PACKET_TYPE_SUB_KEY].popitem()
         packet_data["signatures"] = []
         not_enough_sigs_bundle[PACKET_TYPE_SUB_KEY][packet] = packet_data
 
         # Duplicate sig to trigger wrong amount signatures
         too_many_sigs_bundle = deepcopy(self.raw_key_bundle)
-        packet, packet_data = too_many_sigs_bundle[
-            PACKET_TYPE_SUB_KEY
-        ].popitem()
+        packet, packet_data = too_many_sigs_bundle[PACKET_TYPE_SUB_KEY].popitem()
         packet_data["signatures"] = packet_data["signatures"] * 2
         too_many_sigs_bundle[PACKET_TYPE_SUB_KEY][packet] = packet_data
 
         # Tamper with primary key to trigger signature verification error
         invalid_sig_bundle = deepcopy(self.raw_key_bundle)
-        invalid_sig_bundle[PACKET_TYPE_PRIMARY_KEY][
-            "packet"
-        ] = invalid_sig_bundle[PACKET_TYPE_PRIMARY_KEY]["packet"][:-1]
+        invalid_sig_bundle[PACKET_TYPE_PRIMARY_KEY]["packet"] = invalid_sig_bundle[
+            PACKET_TYPE_PRIMARY_KEY
+        ]["packet"][:-1]
 
         test_data = [
             (bad_subkey_bundle, "Pubkey packet version '3' not supported"),
@@ -485,15 +464,10 @@ class TestCommon(unittest.TestCase):
         ]
 
         for bundle, expected_msg in test_data:
-            with patch("securesystemslib.gpg.common.log") as mock_log:
+            with patch("securesystemslib._gpg.common.log") as mock_log:
                 _get_verified_subkeys(bundle)
                 msg = str(mock_log.info.call_args[0][0])
-                self.assertTrue(
-                    expected_msg in msg,
-                    "'{}' not in '{}'".format(  # pylint: disable=consider-using-f-string
-                        expected_msg, msg
-                    ),
-                )
+                self.assertTrue(expected_msg in msg, f"'{expected_msg}' not in '{msg}'")
 
     def test_get_verified_subkeys(self):
         """Test correct assignment of subkey expiration date in
@@ -501,18 +475,14 @@ class TestCommon(unittest.TestCase):
         subkeys = _get_verified_subkeys(self.raw_expired_key_bundle)
         # Test subkey with validity period 175451, i.e. ~ 2 days
         self.assertTrue(
-            subkeys["0ce427fa3f0f50bc83a4a760ed95e1581691db4d"].get(
-                "validity_period"
-            )
-            == 175451
+            subkeys["0ce427fa3f0f50bc83a4a760ed95e1581691db4d"].get("validity_period")
+            == 175451  # noqa: PLR2004
         )
 
         # Test subkey  without validity period, i.e. it does not expire
         self.assertTrue(
-            subkeys[  # pylint: disable=singleton-comparison
-                "70cfabf1e2f1dc60ac5c7bca10cd20d3d5bcb6ef"
-            ].get("validity_period")
-            == None
+            subkeys["70cfabf1e2f1dc60ac5c7bca10cd20d3d5bcb6ef"].get("validity_period")
+            is None
         )
 
     def test_get_pubkey_bundle_errors(self):
@@ -553,9 +523,7 @@ class TestCommon(unittest.TestCase):
                 parse_signature_packet(data)
             self.assertTrue(
                 expected_error_str in str(ctx.exception),
-                "'{}' not in '{}'".format(  # pylint: disable=consider-using-f-string
-                    expected_error_str, str(ctx.exception)
-                ),
+                f"'{expected_error_str}' not in '{str(ctx.exception)}'",
             )
 
 
@@ -570,36 +538,32 @@ class TestGPGRSA(unittest.TestCase):
     unsupported_subkey_keyid = "611A9B648E16F54E8A7FAD5DA51E8CDF3B06524F"
     expired_key_keyid = "E8AC80C924116DABB51D4B987CB07D6D2C199C7C"
 
-    keyid_768C43 = "7B3ABB26B97B655AB9296BD15B0BD02E1C768C43"  # pylint: disable=invalid-name
+    keyid_768C43 = "7B3ABB26B97B655AB9296BD15B0BD02E1C768C43"  # noqa: N815
 
     @classmethod
-    def setUpClass(self):  # pylint: disable=bad-classmethod-argument
+    def setUpClass(cls):
         # Create directory to run the tests without having everything blow up
-        self.working_dir = os.getcwd()
+        cls.working_dir = os.getcwd()
 
         # Find demo files
         gpg_keyring_path = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "rsa"
         )
 
-        self.test_dir = os.path.realpath(tempfile.mkdtemp())
-        self.gnupg_home = "rsa"
-        shutil.copytree(
-            gpg_keyring_path, os.path.join(self.test_dir, self.gnupg_home)
-        )
-        os.chdir(self.test_dir)
+        cls.test_dir = os.path.realpath(tempfile.mkdtemp())
+        cls.gnupg_home = "rsa"
+        shutil.copytree(gpg_keyring_path, os.path.join(cls.test_dir, cls.gnupg_home))
+        os.chdir(cls.test_dir)
 
     @classmethod
-    def tearDownClass(self):  # pylint: disable=bad-classmethod-argument
+    def tearDownClass(cls):
         """Change back to initial working dir and remove temp test directory."""
-        os.chdir(self.working_dir)
-        shutil.rmtree(
-            self.test_dir, onerror=GPGTestUtils.ignore_not_found_error
-        )
+        os.chdir(cls.working_dir)
+        shutil.rmtree(cls.test_dir, onerror=GPGTestUtils.ignore_not_found_error)
 
     def test_export_pubkey_error(self):
         """Test correct error is raised if function called incorrectly."""
-        with self.assertRaises(ValueError):
+        with self.assertRaises(KeyNotFoundError):
             export_pubkey("not-a-key-id")
 
     def test_export_pubkey(self):
@@ -615,18 +579,12 @@ class TestGPGRSA(unittest.TestCase):
 
         # load the equivalent ssh key, and make sure that we get the same RSA key
         # parameters
-        ssh_key_basename = (
-            "{}.ssh".format(  # pylint: disable=consider-using-f-string
-                self.default_keyid
-            )
-        )
+        ssh_key_basename = f"{self.default_keyid}.ssh"
         ssh_key_path = os.path.join(self.gnupg_home, ssh_key_basename)
         with open(ssh_key_path, "rb") as fp:
             keydata = fp.read()
 
-        ssh_key = serialization.load_ssh_public_key(
-            keydata, backends.default_backend()
-        )
+        ssh_key = serialization.load_ssh_public_key(keydata, backends.default_backend())
 
         self.assertEqual(
             ssh_key.public_numbers().n, our_exported_key.public_numbers().n
@@ -644,9 +602,7 @@ class TestGPGRSA(unittest.TestCase):
         self.assertFalse(self.unsupported_subkey_keyid.lower() in subkey_keyids)
 
         # When passing the subkey keyid we also export the whole keybundle
-        key_data2 = export_pubkey(
-            self.signing_subkey_keyid, homedir=self.gnupg_home
-        )
+        key_data2 = export_pubkey(self.signing_subkey_keyid, homedir=self.gnupg_home)
         self.assertDictEqual(key_data, key_data2)
 
     def test_export_pubkeys(self):
@@ -655,7 +611,6 @@ class TestGPGRSA(unittest.TestCase):
             [self.default_keyid, self.keyid_768C43], homedir=self.gnupg_home
         )
 
-        ANY_PUBKEY_DICT_SCHEMA.check_match(key_dict)
         self.assertListEqual(
             sorted([self.default_keyid.lower(), self.keyid_768C43.lower()]),
             sorted(key_dict.keys()),
@@ -705,8 +660,8 @@ class TestGPGRSA(unittest.TestCase):
             del os.environ["GNUPGHOME"]
 
     def test_create_signature_with_expired_key(self):
-        """Test signing with expired key raises gpg CommandError."""
-        with self.assertRaises(CommandError) as ctx:
+        """Test signing with expired key raises OSError."""
+        with self.assertRaises(OSError) as ctx:
             create_signature(
                 b"livestock",
                 keyid=self.expired_key_keyid,
@@ -715,10 +670,7 @@ class TestGPGRSA(unittest.TestCase):
 
         expected = "returned non-zero exit status '2'"
         self.assertTrue(
-            expected in str(ctx.exception),
-            "{} not in {}".format(  # pylint: disable=consider-using-f-string
-                expected, ctx.exception
-            ),
+            expected in str(ctx.exception), f"{expected} not in {ctx.exception}"
         )
 
     def test_verify_signature_with_expired_key(self):
@@ -741,10 +693,7 @@ class TestGPGRSA(unittest.TestCase):
         )
         self.assertTrue(
             expected == str(ctx.exception),
-            "\nexpected: {}"  # pylint: disable=consider-using-f-string
-            "\ngot:      {}".format(  # pylint: disable=consider-using-f-string
-                expected, ctx.exception
-            ),
+            f"\nexpected: {expected}" "\ngot:      {ctx.exception}",
         )
 
 
@@ -756,27 +705,25 @@ class TestGPGDSA(unittest.TestCase):
     default_keyid = "C242A830DAAF1C2BEF604A9EF033A3A3E267B3B1"
 
     @classmethod
-    def setUpClass(self):  # pylint: disable=bad-classmethod-argument
+    def setUpClass(cls):
         # Create directory to run the tests without having everything blow up
-        self.working_dir = os.getcwd()
-        self.test_dir = os.path.realpath(tempfile.mkdtemp())
-        self.gnupg_home = "dsa"
+        cls.working_dir = os.getcwd()
+        cls.test_dir = os.path.realpath(tempfile.mkdtemp())
+        cls.gnupg_home = "dsa"
 
         # Find keyrings
         keyrings = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "dsa"
         )
 
-        shutil.copytree(keyrings, os.path.join(self.test_dir, self.gnupg_home))
-        os.chdir(self.test_dir)
+        shutil.copytree(keyrings, os.path.join(cls.test_dir, cls.gnupg_home))
+        os.chdir(cls.test_dir)
 
     @classmethod
-    def tearDownClass(self):  # pylint: disable=bad-classmethod-argument
+    def tearDownClass(cls):
         """Change back to initial working dir and remove temp test directory."""
-        os.chdir(self.working_dir)
-        shutil.rmtree(
-            self.test_dir, onerror=GPGTestUtils.ignore_not_found_error
-        )
+        os.chdir(cls.working_dir)
+        shutil.rmtree(cls.test_dir, onerror=GPGTestUtils.ignore_not_found_error)
 
     def test_export_pubkey(self):
         """export a public key and make sure the parameters are the right ones:
@@ -790,18 +737,12 @@ class TestGPGDSA(unittest.TestCase):
         our_exported_key = dsa_create_pubkey(key_data)
 
         # load same key, pre-exported with 3rd-party tooling
-        pem_key_basename = (
-            "{}.pem".format(  # pylint: disable=consider-using-f-string
-                self.default_keyid
-            )
-        )
+        pem_key_basename = f"{self.default_keyid}.pem"
         pem_key_path = os.path.join(self.gnupg_home, pem_key_basename)
         with open(pem_key_path, "rb") as fp:
             keydata = fp.read()
 
-        pem_key = serialization.load_pem_public_key(
-            keydata, backends.default_backend()
-        )
+        pem_key = serialization.load_pem_public_key(keydata, backends.default_backend())
 
         # make sure keys match
         self.assertEqual(
@@ -855,27 +796,25 @@ class TestGPGEdDSA(unittest.TestCase):
     default_keyid = "4E630F84838BF6F7447B830B22692F5FEA9E2DD2"
 
     @classmethod
-    def setUpClass(self):  # pylint: disable=bad-classmethod-argument
+    def setUpClass(cls):
         # Create directory to run the tests without having everything blow up
-        self.working_dir = os.getcwd()
-        self.test_dir = os.path.realpath(tempfile.mkdtemp())
-        self.gnupg_home = "dsa"
+        cls.working_dir = os.getcwd()
+        cls.test_dir = os.path.realpath(tempfile.mkdtemp())
+        cls.gnupg_home = "dsa"
 
         # Find keyrings
         keyrings = os.path.join(
             os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "eddsa"
         )
 
-        shutil.copytree(keyrings, os.path.join(self.test_dir, self.gnupg_home))
-        os.chdir(self.test_dir)
+        shutil.copytree(keyrings, os.path.join(cls.test_dir, cls.gnupg_home))
+        os.chdir(cls.test_dir)
 
     @classmethod
-    def tearDownClass(self):  # pylint: disable=bad-classmethod-argument
+    def tearDownClass(cls):
         """Change back to initial working dir and remove temp test directory."""
-        os.chdir(self.working_dir)
-        shutil.rmtree(
-            self.test_dir, onerror=GPGTestUtils.ignore_not_found_error
-        )
+        os.chdir(cls.working_dir)
+        shutil.rmtree(cls.test_dir, onerror=GPGTestUtils.ignore_not_found_error)
 
     def test_gpg_sign_and_verify_object_with_default_key(self):
         """Create a signature using the default key on the keyring"""
